Fermi 3D — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# Fermi 3D

These examples demonstrate the Fermi3D plotting capabilities.

Symmetry does not currently work! Make sure for fermi surface calculations turn off symmetry

Plotting fermi3d plain

Plotting fermi3d plain

Plotting fermi3d isoslider

Plotting fermi3d isoslider

Plotting fermi3d spin_texture

Plotting fermi3d spin_texture

Plotting fermi3d isovalue_gif

Plotting fermi3d isovalue_gif

Showing how to get van alphen fequencies from the fermi surface

Showing how to get van alphen fequencies from the fermi surface

Plotting fermi3d spin-polarized

Plotting fermi3d spin-polarized

Plotting with Configurations in pyprocar

Plotting with Configurations in pyprocar

Plotting fermi3d cross_section

Plotting fermi3d cross_section